@@ -10,6 +10,12 @@ import logging
 import os
 import sys
 
+# Filter spurious Cython warnings re: numpy
+# Via: https://github.com/numpy/numpy/pull/432
+import warnings
+warnings.filterwarnings("ignore", message="numpy.dtype size changed")
+warnings.filterwarnings("ignore", message="numpy.ufunc size changed")
+
 # If running headless, use a suitable GUI-less plotting backend
 if not os.environ.get('DISPLAY'):
     import matplotlib
@@ -130,7 +136,7 @@ def _cmd_batch(args):
                 pool.submit(batch.batch_run_sample,
                             bam, args.targets, args.antitargets, args.reference,
                             args.output_dir, args.male_reference, args.scatter,
-                            args.diagram, args.rlibpath, args.count_reads,
+                            args.diagram, args.rscript_path, args.count_reads,
                             args.drop_low_coverage, args.method, procs_per_bam)
     else:
         logging.info("No tumor/test samples (but %d normal/control samples) "
@@ -162,8 +168,6 @@ P_batch.add_argument('-p', '--processes',
         help="""Number of subprocesses used to running each of the BAM files in
                 parallel. Without an argument, use the maximum number of
                 available CPUs. [Default: process each BAM in serial]""")
-P_batch.add_argument("--rlibpath", metavar="DIRECTORY",
-        help=argparse.SUPPRESS)
 P_batch.add_argument("--rscript-path", metavar="PATH", default="Rscript",
         help="""Path to the Rscript excecutable to use for running R code.
                 Use this option to specify a non-default R installation.
@@ -624,7 +628,6 @@ def _cmd_segment(args):
                                            skip_low=args.drop_low_coverage,
                                            skip_outliers=args.drop_outliers,
                                            save_dataframe=bool(args.dataframe),
-                                           rlibpath=args.rlibpath,
                                            rscript_path=args.rscript_path,
                                            processes=args.processes)
     if args.dataframe:
@@ -664,8 +667,6 @@ P_segment.add_argument("--drop-outliers", metavar="FACTOR",
                 quantile away from the average within a rolling window.
                 Set to 0 for no outlier filtering.
                 [Default: %(default)g]""")
-P_segment.add_argument("--rlibpath", metavar="DIRECTORY",
-        help=argparse.SUPPRESS)
 P_segment.add_argument("--rscript-path", metavar="PATH", default="Rscript",
         help="""Path to the Rscript excecutable to use for running R code.
                 Use this option to specify a non-default R installation.
@@ -1488,9 +1489,10 @@ P_import_rna.add_argument('-g', '--gene-resource',
 P_import_rna.add_argument('-c', '--correlations', metavar="FILE",
         help="""Correlation of each gene's copy number with
                 expression. Output of cnv_expression_correlate.py.""")
-P_import_rna.add_argument('--max-log2', metavar="FLOAT", default=3.0,
+P_import_rna.add_argument('--max-log2',
+        metavar="FLOAT", default=3.0, type=float,
         help="""Maximum log2 value in output. Observed values above this limit
-                will be replaced with this value.""")
+                will be replaced with this value. [Default: %(default)s]""")
 P_import_rna.add_argument('-n', '--normal', nargs='+', default=[],
         help="""Normal samples (same format as `gene_counts`) to be used as a
                 control to when normalizing and re-centering gene read depth
