@@ -52,11 +52,9 @@ def aggregate_gene_counts(filenames):
     prev_row_count = None
     sample_cols = {}
     for fname in filenames:
-        d = (pd.read_table(fname,
-                           header=None,
-                           comment="_",
-                           names=["gene_id", "expected_count"],
-                           converters={"gene_id": rna.before(".")})
+        d = (pd.read_csv(fname, sep='\t', comment="_", header=None,
+                         names=["gene_id", "expected_count"],
+                         converters={"gene_id": rna.before(".")})
              .set_index("gene_id"))
              # .drop(["__no_feature", "__ambiguous", "__too_low_aQual",
              # "__not_aligned", "__alignment_not_unique"]))
@@ -89,14 +87,14 @@ def aggregate_rsem(fnames):
     length_cols = []
     length_colname = 'length'  # or: 'effective_length'
     for fname in fnames:
-        # NB: read_table(index_col=_) works independently of combine=, dtype=
-        #   so index column needs to be processed separately
+        # NB: read_csv(index_col=_) works independently of combine=, dtype=
+        #   so index column needs to be set after parsing, not during.
         #   https://github.com/pandas-dev/pandas/issues/9435
-        d = pd.read_table(fname,
-                          usecols=['gene_id', length_colname, 'expected_count'],
-                          #  index_col='gene_id',
-                          converters={'gene_id': rna.before('.')}
-                         ).set_index('gene_id')
+        d = pd.read_csv(fname, sep='\t',
+                        usecols=['gene_id', length_colname, 'expected_count'],
+                        #  index_col='gene_id',
+                        converters={'gene_id': rna.before('.')}
+                        ).set_index('gene_id')
         if prev_row_count is None:
             prev_row_count = len(d)
         elif len(d) != prev_row_count:
