@@ -80,24 +80,17 @@ def into_ranges(source, dest, src_col, default, summary_func):
 def iter_ranges(table, chrom, starts, ends, mode):
     """Iterate through sub-ranges."""
     assert mode in ('inner', 'outer', 'trim')
-    if chrom:
-        assert isinstance(chrom, basestring)  # ENH: accept array?
-        try:
-            table = table[table['chromosome'] == chrom]
-        except KeyError:
-            raise KeyError("Chromosome %s is not in this probe set" % chrom)
-
-    for region_idx, start_val, end_val in idx_ranges(table, None, starts, ends,
+    for region_idx, start_val, end_val in idx_ranges(table, chrom, starts, ends,
             'inner' if mode == 'inner' else 'outer'):
         subtable = table.iloc[region_idx]
         if mode == 'trim':
             subtable = subtable.copy()
             # Update 5' endpoints to the boundary
             if start_val:
-                subtable.start = subtable.start.clip_lower(start_val)
+                subtable.start = subtable.start.clip(lower=start_val)
             # Update 3' endpoints to the boundary
             if end_val:
-                subtable.end = subtable.end.clip_upper(end_val)
+                subtable.end = subtable.end.clip(upper=end_val)
         yield subtable
 
 
@@ -139,7 +132,7 @@ def idx_ranges(table, chrom, starts, ends, mode):
         # Don't be fooled by nested bins
         if ((ends is not None and len(ends)) and
             (starts is not None and len(starts))
-        ) and not _monotonic(table.end):
+        ) and not table.end.is_monotonic_increasing:
             # At least one bin is fully nested -- account for it
             irange_func = _irange_nested
         else:
@@ -213,12 +206,3 @@ def venn(table, other, mode):
     #       (is that faster? probably not)
     #   -> 'jaccard' does math with it...
     return table
-
-
-# Shim for pandas 0.18.1 (chapmanb/bcbio-nextgen#1836)
-if hasattr(pd.Series, 'is_monotonic_increasing'):
-    def _monotonic(ser):
-        return ser.is_monotonic_increasing
-else:
-    def _monotonic(ser):
-        return (np.diff(ser) >= 0).all()
